/* ----------------------------------------------------------------------------
 * gxinterface -- Gtk+ Extended Interface
 * Module and module manager Header
 *
 * ----------------------------------------------------------------------------
 * copyright © 2006, 2007, 2008, 2009, 2010 Jérôme BENHAÏM <benhaimjerome@gmail.com>
 *
 * ----------------------------------------------------------------------------
 *
 *   This file is part of GxInterface.
 *
 *	 GxInterface is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------------------------------
 */
#ifndef Gemod_H
	#define Gemod_H
	/* gnome */
	/* app */
	#include "debug.h"
    #include "common.h"
	#include <gtkmm.h>
	#include <glibmm/module.h>

    #define MODULE_UI_DIR "/media/a77eb293-65e8-4afa-abc0-40d0dbbe7075/gsysex/gxsynth/src/"

/* GTK Module structure */
/*
 ***** Gx_Module *****
 */
class Gx_module {	
	private:
    	Glib::RefPtr<Gtk::Builder> refXml;
		Glib::Module * module;		
		gboolean set_refxml(Glib::ustring);
		struct st_extPath{
			Glib::ustring ext;
			Glib::ustring name;
			Glib::ustring filename;
			Glib::ustring path;
			Glib::ustring file;
		} ;
		struct st_mod { 
			struct st_extPath extpath;
			Glib::ustring type;
			Glib::ustring cat;
			Glib::ustring desc;
			guint index;
		} mod;
		virtual void attach_signals();
		virtual void dettach_signals();
		/* load module ²*/
		gboolean load(Glib::ustring,guint);
		void extractPath(Glib::ustring);
	protected: 
		/* thread func */
		Glib::RefPtr<Gtk::Builder> (*module_func) (Glib::ustring, gint);
		template <class widgetType>
		widgetType* get_gwidget(Glib::ustring widget_name) {
			widgetType* wid;
			refXml->get_widget(widget_name,wid);
			return (wid);
		};
		Glib::RefPtr<Glib::Object> get_gobject(Glib::ustring object_name) {
			return (refXml->get_object(object_name));
		};
	public:	
		Glib::RefPtr<Gtk::Builder> get_refxml();
		Gtk::VBox* get_module(){
			return get_gwidget<Gtk::VBox>("vbox_main");
		}
		/* gx_module as .ui */
		Gx_module(Glib::ustring);
		/* gx_module as .la */
		Gx_module(Glib::ustring, guint);
		/* for array of gx module */
		Gx_module();
		~Gx_module();
		/* */
		void set_module_name(Glib::ustring);
		/* set module */
		void set_mod(Glib::ustring, guint);
		void unset_mod();
		
		std::string get_name();
		std::string get_file();
		std::string get_type();
		std::string get_cat();
		std::string get_desc();
		std::string get_ext();
		std::string get_filename();
		std::string get_path();
};
/*
 ***** Gemod *****
 */
class Gemod : public Gx_module {
	private:
		Gx_module * modules;
		guint nb_mod, max_modules;
		/* callback function */
		virtual void attach_signals();
		virtual void dettach_signals();
		/* callback functions */
		virtual void on_menu_add_module_event();
		virtual void on_menu_del_module_event();
	protected:
		
		/* return : name of the module searched by index
		 * guint : index of searched module
		 */
		Glib::ustring get_module_name(guint);
		/* return : index of the module asked by name of the module or -1 if not exist
		 * ustring : name of the searched module
		 */
		gint get_module_index(Glib::ustring);
		
		/* objet specifique a l interface de base */		
		Gtk::VBox* get_module_root(Glib::ustring name);
		Gtk::VBox* get_module_root(guint);
		/* fonctions interface  */
		virtual gboolean add_module(Glib::ustring);
		virtual gboolean del_module(Glib::ustring);
		/* Menu construction */
		virtual gboolean add_menu(Glib::ustring, Glib::ustring);
		virtual gboolean del_menu(Glib::ustring);
		/* submenu constructor 
		 * return : created Menu
		 * ustring* : array of name(s) of the items in menu 
		 */
		virtual Gtk::Menu * create_submenu(Glib::ustring*);
		/* return : MenuItem dynamically created 
		 * ustring : name of the menu in .ui
		 */
		virtual Gtk::MenuItem * get_menu_dyn(Glib::ustring);
		/* load module 
		 * accept .la or .ui
		 * return : 1 if good else 0
		 * ustring : name of the .la or .ui to load
		 */
		gboolean load(Glib::ustring);
	public:
		/* return the main Gtk::Window */
		Gtk::Window* get_main();
		/* for gemod as base module manager not as a module 
		 * ustring name of the .ui
		 */
		Gemod(Glib::ustring);
		/* for gemod as module (inheritance) 
		 * ustring : the module_name, name of the .la
		 * guint : index of the module in the module manager
		 */
		Gemod(Glib::ustring,guint);
		/* for gemod as module with specified number of modules 
		 * ustring : the module_name, name of the .la
		 * guint : index of the module in the module manager
		 * guint : number of module in the module
		 */
		Gemod(Glib::ustring,guint,guint);
		/*Gemod();	*/
		~Gemod();
};
#endif  /* gemod_H */
