 /* sysex_edit.h -- sysex
 * Modules Synthetiseur interface definition
 * ----------------------------------------------------------------------------
 * copyright (c) 2006 Jérôme BENHAÏM <benhaimjerome@gmail.com>,
 * 					  Jean-Michel THIEMONGE
 * ----------------------------------------------------------------------------
 * This program is free software ; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation ; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY ; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * ----------------------------------------------------------------------------
 */
 #ifndef sysexedit_H
	#define sysexedit_H
	#include <gxinterface-0.0.1/gxinterface/common.h>
	#include <gxinterface-0.0.1/gxinterface/debug.h>
	#include <gxinterface-0.0.1/gxinterface/lang.h>
	#include <gxinterface-0.0.1/gxinterface/gemod.h>
	#include <gxinterface-0.0.1/gxinterface/gxthread.h>
	/* dx7 specific */
	#include "dx7sysex.h"

	/* Glib */
	#include <glib.h>
	/*	Alsa */
	#include <alsa/asoundlib.h>
	// Liste des Class	
	/* class générique */
	#define IMAGE_DIR "/home/meshmesh/gxinterface/gxsynth/data/images/"
/*mod_synth.cc
 *timer 
*create/delete midi
*load/write bank 
*receive/send sysex
*charger/decharger synth
*attache/detache midi one by synth
*/
extern "C" {	
	Glib::RefPtr<Gtk::Builder> LoadPlug(Glib::ustring, guint);
}

class SysexEdit : Thread, public Gemod  {
	private:
		/*** sysex ***/
		/* message */
		static const guint8 sysex_size=7;
		/* static fix yamaha id */
		static const guint8 id_fabricant=0x43;
		/* set select_channel */
		static const guint8 channel=0xF0;
		/* set set_sud_status */
		static const guint8 sub_status=0x10;
		guchar msg[7];
		/* bank */
		St_dx7sysex<1> bank_1_origin;
		St_dx7sysex<1> bank_1_modif;
		St_dx7sysex<32> bank_32_origin;
		St_dx7sysex<32> bank_32_modif;
		St_dx7sysex<128> bank_128_origin;
		St_dx7sysex<128> bank_128_modif;
		Glib::RefPtr<Gio::File> bank_file;
		Glib::RefPtr<Gio::DataInputStream> data_stream;
		/*** ALSA ***/
		/* midi_receive;*/
		/*snd_rawmidi_t *handle_in ,*handle_out ;*/
		snd_seq_t* seq_handle;	
		snd_seq_system_info_t* info;
		snd_seq_event_t* ev;
		size_t in_buff_size, out_buff_size;	
  		gint port_in, port_out;	
		/* seq queue */
		gint spfd;
		struct pollfd *pfd;  
		/* ui */
		
	protected:
		// modules synth interface ( a deplacerdans class dx7 )
		Glib::RefPtr<Gtk::ListStore> m_refListStore ;
		void attach_signals();
		void dettach_signals();
		/* MIDI, */
		void connect_midi();
		void deconnect_midi();
		void listen_midi();
		void send_midi();
		/* sound bank */
		void clean_bank();
		/* raw bank */
		void load_raw_bank(Glib::RefPtr<Gio::File>);
		void save_raw_bank(Glib::RefPtr<Gio::File>);
		void save_raw_bank_as(Glib::RefPtr<Gio::File>);
		/* sysex bank */
		void load_sys_bank(Glib::RefPtr<Gio::File>);
		void save_sys_bank(Glib::RefPtr<Gio::File>);
		void save_sys_bank_as(Glib::RefPtr<Gio::File>);
		/* voice load  */
		void seek_voice(guint, st_dx7sysex_1*);
		void set_voice(st_dx7sysex_1*);
		/* Thread function  */
		bool Run();
		
		/* events */
		void on_treeview_row_activated(const Gtk::TreeModel::Path&,Gtk::TreeViewColumn*);
		void on_treeview_row_clicked();
		void on_bank_select();
		/* general algo */ 
		void on_algo_event();
	    void on_feedback_event();	    
	    void on_transpose_event();	    
		void on_oks_event();
		/* general lfo */
		void on_lfo_wav_event();
		void on_lfo_sync_event();
		void on_speed_event();
		void on_delay_event();
		void on_pmd_event();
		void on_amd_event();
		/* lfo modulation */
		void on_pms_event();

		/* pitch eg*/
		void on_pitch_rt1_event();
		void on_pitch_rt2_event();
		void on_pitch_rt3_event();
		void on_pitch_rt4_event();
		void on_pitch_lvl1_event();
		void on_pitch_lvl2_event();
		void on_pitch_lvl3_event();
		void on_pitch_lvl4_event();

		
		/* op1 */
		void on_freq_mode_op1_event();
		void on_freq_coarse_op1_event();
		void on_freq_fine_op1_event();
		void on_dtun_op1_event();	
		/* op1 EG*/
		void on_eg_rt1_op1_event();
		void on_eg_rt2_op1_event();
		void on_eg_rt3_op1_event();
		void on_eg_rt4_op1_event();
		void on_eg_lvl1_op1_event();
		void on_eg_lvl2_op1_event();
		void on_eg_lvl3_op1_event();
		void on_eg_lvl4_op1_event();
		/* op1 VOLUME*/
		void on_krs_op1_event();
		void on_kvs_op1_event();
		void on_lvl_op1_event();
		
		void on_mute_op1_event();
		
		/* op2 */
		void on_freq_coarse_op2_event();
	  			
		/* op3 */
		void on_freq_coarse_op3_event();
		/* op4 */
		void on_freq_coarse_op4_event();
		/* op5 */
		void on_freq_coarse_op5_event();
		/* op6 */
		void on_freq_coarse_op6_event();

	public:
		SysexEdit(Glib::ustring, guint);
		~SysexEdit();		
};


#endif /* sysexedit_H */
